@@ -2,7 +2,7 @@
 #ifndef _GLIBMM_CONTAINERHANDLE_SHARED_H
 #define _GLIBMM_CONTAINERHANDLE_SHARED_H
 
-/* $Id: containerhandle_shared.h,v 1.5 2004/03/14 12:32:44 murrayc Exp $ */
+/* $Id: containerhandle_shared.h,v 1.6 2004/03/30 12:06:01 murrayc Exp $ */
 
 /* Copyright (C) 2002 The gtkmm Development Team
  *
@@ -57,8 +57,8 @@ namespace Glib
 enum OwnershipType
 {
   OWNERSHIP_NONE = 0,
-  OWNERSHIP_SHALLOW,
-  OWNERSHIP_DEEP
+  OWNERSHIP_SHALLOW, //Release the list, but not its elements, when the container is deleted
+  OWNERSHIP_DEEP //Release the list, and its elements, when the container is deleted.
 };
 
 
