@@ -1,5 +1,5 @@
 // -*- c++ -*-
-/* $Id: main.cc,v 1.5 2004/03/03 20:35:46 murrayc Exp $ */
+/* $Id: main.cc,v 1.6 2004/03/20 14:38:40 mschulze Exp $ */
 
 /* Copyright (C) 2002 The gtkmm Development Team
  *
@@ -67,7 +67,7 @@ void* SourceConnectionNode::notify(void* data)
   {
     GSource* s = self->source_;  
     self->source_ = 0;
-    g_source_destroy(self->source_);
+    g_source_destroy(s);
 
     delete self;
   }
